pub enum MathError {
NotQuadratic,
SingularMatrix,
}Expand description
Errors returned by math operations in this crate.
Variants
NotQuadratic
The a coefficient is zero, so the equation is not quadratic.
SingularMatrix
The matrix cannot be inverted or used with Cramer’s rule because its determinant is zero.